@@ -7,7 +7,7 @@ size(IntroWindow)<-c(800,600)
 IntroTextframe<-gframe(horizontal = FALSE, container=IntroWindow,where="center")
 IntroTextMessage1<-glabel('Welcome to StatCharrms',container=IntroTextframe,where="center") #Title1
 font(IntroTextMessage1)<-list(size=34)
-IntroTextMessage2<-glabel('v0.90 April 18, 2017',container=IntroTextframe,where="center") #Title2  #Update This
+IntroTextMessage2<-glabel('v0.90.6 November 07, 2017',container=IntroTextframe,where="center") #Title2  #Update This
 font(IntroTextMessage2)<-list(size=16)
 IntroTextMessage3<-glabel('Beta -Developmental-',container=IntroTextframe,where="center") #Title2
 font(IntroTextMessage3)<-list(size=16)
@@ -40,4 +40,27 @@ quit("no")
 font(QuitButton)<-list(size=16)
 
 visible(IntroWindow)<-TRUE
+
+
+
+if (sessionInfo()$otherPkgs$RGtk2$Version == "2.20.33"){
+Message<-'StatCharrms does not work with RGtk2 version 2.20.33.
+Please install RGtk2 version 2.20.31.
+Directions on how to install a specific version of a package can be found at:\n
+https://support.rstudio.com/hc/en-us/articles/219949047-Installing-older-versions-of-packages
+\nOr with the "versions" package using the install.versions function.'
+ 
+ PopWindow<-gwindow("Alert!", width = 480, height = 200, 
+        visible = FALSE)
+  Textframe <- gframe(horizontal = FALSE, container = PopWindow, 
+        expand = TRUE, fill = TRUE)
+    TextMessage <- gtext(Message, container = Textframe, expand = TRUE, 
+        fill = TRUE)
+    Okbutton <- gbutton("OK", container = Textframe, handler = function(h, 
+        ...) {
+        dispose(PopWindow)
+    })
+    visible(PopWindow) <- TRUE		
+message(Message)
+}
 }
